#
# spec file for package ghc-zlib
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name zlib
%global pkgver %{pkg_name}-%{version}
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        0.6.3.0
Release:        6.1
Summary:        Compression and decompression in the gzip and zlib formats
License:        BSD-2-Clause
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
Source1:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/revision/5.cabal#/%{pkg_name}.cabal
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-base-devel
BuildRequires:  ghc-base-prof
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-bytestring-prof
BuildRequires:  ghc-rpm-macros
BuildRequires:  zlib-devel
ExcludeArch:    %{ix86}
%if %{with tests}
BuildRequires:  ghc-QuickCheck-devel
BuildRequires:  ghc-QuickCheck-prof
BuildRequires:  ghc-tasty-devel
BuildRequires:  ghc-tasty-prof
BuildRequires:  ghc-tasty-quickcheck-devel
BuildRequires:  ghc-tasty-quickcheck-prof
%endif

%description
This package provides a pure interface for compressing and decompressing
streams of data represented as lazy 'ByteString's. It uses the
<https://en.wikipedia.org/wiki/Zlib zlib C library> so it has high performance.
It supports the "zlib", "gzip" and "raw" compression formats.

It provides a convenient high level API suitable for most tasks and for the few
cases where more control is needed it provides access to the full zlib feature
set.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires:       zlib-devel
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%package -n ghc-%{pkg_name}-doc
Summary:        Haskell %{pkg_name} library documentation
Requires:       ghc-filesystem
BuildArch:      noarch

%description -n ghc-%{pkg_name}-doc
This package provides the Haskell %{pkg_name} library documentation.

%package -n ghc-%{pkg_name}-prof
Summary:        Haskell %{pkg_name} profiling library
Requires:       ghc-%{pkg_name}-devel = %{version}-%{release}
Supplements:    (ghc-%{pkg_name}-devel and ghc-prof)

%description -n ghc-%{pkg_name}-prof
This package provides the Haskell %{pkg_name} profiling library.

%prep
%autosetup -n %{pkg_name}-%{version}
cp -p %{SOURCE1} %{pkg_name}.cabal

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc README.md changelog examples

%files -n ghc-%{pkg_name}-doc -f ghc-%{pkg_name}-doc.files
%license LICENSE

%files -n ghc-%{pkg_name}-prof -f ghc-%{pkg_name}-prof.files

%changelog
* Sun Jun 23 2024 Peter Simons <psimons@suse.com>
- Update zlib to version 0.6.3.0 revision 5.
  Upstream has revised the Cabal build instructions on Hackage.
* Tue Oct 24 2023 Peter Simons <psimons@suse.com>
- Update zlib to version 0.6.3.0 revision 4.
  Upstream has revised the Cabal build instructions on Hackage.
* Thu Aug 10 2023 Peter Simons <psimons@suse.com>
- Update zlib to version 0.6.3.0 revision 3.
  Upstream has revised the Cabal build instructions on Hackage.
* Fri Jul  7 2023 Peter Simons <psimons@suse.com>
- Update zlib to version 0.6.3.0 revision 2.
  Upstream has revised the Cabal build instructions on Hackage.
* Thu Mar 30 2023 Peter Simons <psimons@suse.com>
- Updated spec file to conform with ghc-rpm-macros-2.5.2.
* Wed Feb  1 2023 Peter Simons <psimons@suse.com>
- Update zlib to version 0.6.3.0 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Wed May  4 2022 Peter Simons <psimons@suse.com>
- Update zlib to version 0.6.3.0.
  Upstream has edited the change log file since the last release in
  a non-trivial way, i.e. they did more than just add a new entry
  at the top. You can review the file at:
  http://hackage.haskell.org/package/zlib-0.6.3.0/src/changelog
* Tue Sep  7 2021 psimons@suse.com
- Update zlib to version 0.6.2.3 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Tue Feb 23 2021 psimons@suse.com
- Update zlib to version 0.6.2.3.
  0.6.2.3 Emily Pillmore <emilypi@cohomolo.gy> February 2021
  * Add support for bytestring-0.11.0.0
* Thu Dec 17 2020 Ondřej Súkup <mimi.vx@gmail.com>
- disable %%{ix86} build
* Tue Aug 18 2020 Peter Simons <psimons@suse.com>
- Replace %%setup -q with the more modern %%autosetup macro.
* Tue Aug  4 2020 psimons@suse.com
- Update zlib to version 0.6.2.2.
  0.6.2.2 Julian Ospald <hasufell@posteo.de> August 2020
  * Bump bundled zlib to 1.2.11, fixes #26
  * New build flag to force use of the bundled zlib C sources, #31
  * Simpler build support for ghcjs, #25
  * Add support for GHC 8.10 / base-4.14, #29
* Tue Jun 16 2020 Peter Simons <psimons@suse.com>
- Re-generate file with latest version of spec-cleaner.
* Thu May  7 2020 Peter Simons <psimons@suse.com>
- Update Cabal file to get more accurate dependency information.
* Fri Nov  8 2019 Peter Simons <psimons@suse.com>
- Drop obsolete group attributes.
* Tue Aug 27 2019 psimons@suse.com
- Update zlib to version 0.6.2.1.
  See also http://pvp.haskell.org/faq
  0.6.2.1 Herbert Valerio Riedel <hvr@gnu.org> August 2019
  * Add support for GHC 8.8 / base-4.13
* Sat Oct 20 2018 Peter Simons <psimons@suse.com>
- Use https URL to refer to bugs.opensuse.org.
* Wed Jul 18 2018 psimons@suse.com
- Cosmetic: replace tabs with blanks, strip trailing white space,
  and update copyright headers with spec-cleaner.
* Mon May 14 2018 psimons@suse.com
- Update zlib to version 0.6.2.
  * New cabal flag 'pkg-config' for discovering 'zlib` via pkg-config(1) (#16)
  * Use CApiFFI where available for cross-compile friendliness (#14)
  * Change the window bits range from 8..15 to 9..15 (#11)
* Thu Aug  3 2017 psimons@suse.com
- Updated with latest spec-cleaner version 0.9.8-8-geadfbbf.
* Sun Oct 30 2016 psimons@suse.com
- Update to version 0.6.1.2 with cabal2obs.
* Sun Jul 10 2016 psimons@suse.com
- Update to version 0.6.1.1 revision 3 with cabal2obs.
* Wed Dec 30 2015 mimi.vx@gmail.com
- update to 0.6.1.1
- regenerated spec file with cabal-rpm
  * Support for concatenated gzip files (multiple back-to-back streams)
  * Fixed warnings with new GHC
  * Fixed testsuite
  * New incremental interface for compression and decompression
  * Provide access to unconsumed trailing data
  * Simplified structured error type, and instance of Exception
  * Fixed memory leak of zlib z_stream C structure
  * More derivied instances (Eq, Show, Typeable, Generic)
* Sat Apr 11 2015 mimi.vx@gmail.com
- update to 0.5.4.2
  * no upstreqm changelog
* Fri Sep 12 2014 peter.trommler@ohm-hochschule.de
- update copyright notice (year) in spec file
* Sat Aug 23 2014 peter.trommler@ohm-hochschule.de
- enable PowerPC builds
* Mon May  6 2013 peter.trommler@ohm-hochschule.de
- update to 0.5.4.1
  * no changelog
- part of Haskell Platform 2013.2 update
- more transparent packaging (fewer macros)
* Thu Dec 27 2012 peter.trommler@ohm-hochschule.de
- fix license tag (intentionally empty 3rd clause)
- expand macro in name tag (help factory-auto)
* Sat Nov 17 2012 peter.trommler@ohm-hochschule.de
- make service localonly for Factory submission
* Tue Oct  2 2012 peter.trommler@ohm-hochschule.de
- update to 0.5.4.0 from upstream (no changelog)
- required by Haskell Platform 2012.4.0.0
* Mon Jun  4 2012 peter.trommler@ohm-hochschule.de
- update to 0.5.3.3 from upstream (no changelog)
- required by Haskell Platform 2012.2.0.0
* Thu Feb 23 2012 peter.trommler@ohm-hochschule.de
- Added BuildRoot for sle11-sp1
* Thu Dec 15 2011 peter.trommler@ohm-hochschule.de
- Added requires zlib-devel
* Thu Dec 15 2011 peter.trommler@ohm-hochschule.de
- Add arches for OBS.
* Thu Dec 15 2011 peter.trommler@ohm-hochschule.de
- Initial packaging.
